import { ButtonHTMLAttributes, MouseEventHandler } from 'react';
import { IconType } from '../Icon';
/**
 * Button
 *
 * It has variant `primary` or `secondary`.
 * Default variant is `primary`.
 * `secondary` button change its color if `accent` property is true.
 *
 */
export declare const NativeButton: import("styled-components").StyledComponent<"button", import("styled-components").DefaultTheme, {
    readonly variant: ButtonVariantType;
    readonly accent: boolean;
    readonly icon?: IconType | undefined;
    readonly visibleFocus: boolean;
}, never>;
declare type BaseElement = HTMLButtonElement;
declare type BaseProps = ButtonHTMLAttributes<BaseElement>;
declare type ButtonType = 'button' | 'submit' | 'reset';
export declare type ButtonVariantType = 'primary' | 'secondary';
export declare type ButtonClickHandler = MouseEventHandler<BaseElement>;
interface BaseButtonProps extends BaseProps {
    /**
     * Specifies the name for a <button> element.
     */
    readonly name?: BaseProps['name'];
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * Specifies the type of button.
     * Default: `button`
     */
    readonly type?: ButtonType;
    /**
     * Button variant.
     * Default: `primary`
     */
    readonly variant?: ButtonVariantType;
    /**
     * If `true` the secondary button gets primary color.
     * Default: `false`
     */
    readonly accent?: boolean;
}
export interface ButtonProps extends BaseButtonProps {
    /**
     * String used to label the button.
     */
    readonly label: string;
    /**
     * The icon element.
     */
    readonly icon?: IconType;
}
export declare const Button: import("react").ForwardRefExoticComponent<ButtonProps & import("react").RefAttributes<HTMLButtonElement>>;
export interface IconButtonProps extends BaseButtonProps {
    /**
     * Icon that shows inside Button.
     */
    readonly icon: IconType;
}
export declare const IconButton: import("react").ForwardRefExoticComponent<IconButtonProps & import("react").RefAttributes<HTMLButtonElement>>;
/**
 * IconTextButton
 *
 * Always has a primary icon and a secondary text
 *
 */
export declare const NativeIconTextButton: import("styled-components").StyledComponent<"button", import("styled-components").DefaultTheme, {
    readonly visibleFocus: boolean;
}, never>;
export interface IconTextButtonProps extends Omit<BaseButtonProps, 'variant' | 'accent'> {
    /**
     * String used to label the button.
     */
    readonly label: string;
    /**
     * The icon element.
     */
    readonly icon: IconType;
}
export declare const IconTextButton: import("react").ForwardRefExoticComponent<IconTextButtonProps & import("react").RefAttributes<HTMLButtonElement>>;
export {};
