"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TextBlock = exports.SpaceBlock = exports.FormSection = exports.ContentListItemWithHover = exports.ContentListItem = exports.ContentDivider = exports.CONTENT_PADDING = void 0;

var _react = require("react");

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _designparams = require("../designparams");

var _Typography = require("../Typography");

var _Divider = require("../Divider");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["text", "caption"],
    _excluded2 = ["title", "children"],
    _excluded3 = ["listHeight", "onHover", "children"];

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * Common padding of content in Dialog/Card
 */
var CONTENT_PADDING = _designparams.spacing.extraLarge;
/**
 * TextBlock
 *
 * Without caption, the block is 40px height.
 * With caption, the block has 8px padding to top and bottom.
 *
 * */

exports.CONTENT_PADDING = CONTENT_PADDING;

var Block = _styledComponents.default.div.withConfig({
  displayName: "Content__Block",
  componentId: "sc-1gz16vj-0"
})(["display:flex;flex-direction:column;", ""], _ref => {
  var {
    hasCaption
  } = _ref;
  return hasCaption ? (0, _styledComponents.css)(["padding:", " 0;"], _designparams.spacing.medium) : (0, _styledComponents.css)(["> *{display:flex;align-items:center;height:", ";}"], _designparams.componentSize.medium);
});

var DefaultText = (0, _styledComponents.default)(_Typography.Typography).withConfig({
  displayName: "Content__DefaultText",
  componentId: "sc-1gz16vj-1"
})(["color:", ";"], _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.color.text01();
});
var Caption = (0, _styledComponents.default)(_Typography.Typography).withConfig({
  displayName: "Content__Caption",
  componentId: "sc-1gz16vj-2"
})(["color:", ";"], _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.color.text03();
});

var TextBlock = _ref4 => {
  var {
    text,
    caption
  } = _ref4,
      props = _objectWithoutProperties(_ref4, _excluded);

  var hasCaption = caption !== undefined;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(Block, _objectSpread(_objectSpread({
    hasCaption: hasCaption
  }, props), {}, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(DefaultText, {
      children: text
    }), caption !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(Caption, {
      variant: "caption",
      children: caption
    }) : undefined]
  }));
};
/**
 * SpaceBlock
 *
 * A block for adjusting space between elements in Dialog/Card.
 *
 * */


exports.TextBlock = TextBlock;

var SpaceBlock = _styledComponents.default.div.withConfig({
  displayName: "Content__SpaceBlock",
  componentId: "sc-1gz16vj-3"
})(["width:100%;height:", ";"], _ref5 => {
  var {
    variant
  } = _ref5;
  return variant === 8 ? _designparams.spacing.medium : variant === 16 ? _designparams.spacing.large : variant === 24 ? _designparams.spacing.extraLarge : _designparams.spacing.huge;
});
/**
 * ContentDivider
 *
 * It shows an edge to edge divider line in a content
 */


exports.SpaceBlock = SpaceBlock;
var ContentDivider = (0, _styledComponents.default)(_Divider.Divider).withConfig({
  displayName: "Content__ContentDivider",
  componentId: "sc-1gz16vj-4"
})(["margin:0 -", ";"], CONTENT_PADDING);
/**
 * FormSection
 *
 * It takes optional title and gives margin-bottom 8px to all children.
 */

exports.ContentDivider = ContentDivider;

var FormContainer = _styledComponents.default.div.withConfig({
  displayName: "Content__FormContainer",
  componentId: "sc-1gz16vj-5"
})(["> *{margin-bottom:", ";}"], _designparams.spacing.medium);

var TitleContainer = _styledComponents.default.div.withConfig({
  displayName: "Content__TitleContainer",
  componentId: "sc-1gz16vj-6"
})(["height:", ";display:flex;align-items:center;color:", ";cursor:default;text-transform:uppercase;"], _designparams.componentSize.medium, _ref6 => {
  var {
    theme
  } = _ref6;
  return theme.color.text04();
});

var GroupTitle = _ref7 => {
  var {
    title
  } = _ref7;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(TitleContainer, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Typography.Typography, {
      variant: "group-title",
      children: title
    })
  });
};

var FormSection = _ref8 => {
  var {
    title,
    children
  } = _ref8,
      props = _objectWithoutProperties(_ref8, _excluded2);

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [title !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(GroupTitle, {
      title: title
    }) : undefined, children !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(FormContainer, _objectSpread(_objectSpread({}, props), {}, {
      children: children
    })) : undefined]
  });
};
/**
 * List parts in a content
 */


exports.FormSection = FormSection;

var ContentListItem = _styledComponents.default.div.withConfig({
  displayName: "Content__ContentListItem",
  componentId: "sc-1gz16vj-7"
})(["margin:0 -", ";padding:0 ", ";cursor:pointer;display:flex;align-items:center;justify-content:space-between;height:", ";&:hover{background-color:", ";}> :first-child{width:100%;}"], CONTENT_PADDING, CONTENT_PADDING, _ref9 => {
  var {
    listHeight
  } = _ref9;
  return listHeight === 'medium' || listHeight === undefined ? _designparams.componentSize.medium : _designparams.componentSize.large;
}, _ref10 => {
  var {
    theme
  } = _ref10;
  return theme.color.background03();
});

exports.ContentListItem = ContentListItem;

var ContentListItemWithHover = _ref11 => {
  var {
    listHeight = 'medium',
    onHover,
    children
  } = _ref11,
      props = _objectWithoutProperties(_ref11, _excluded3);

  var handleMouseEnter = (0, _react.useCallback)(() => {
    onHover(true);
  }, [onHover]);
  var handleMouseLeave = (0, _react.useCallback)(() => {
    onHover(false);
  }, [onHover]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ContentListItem, _objectSpread(_objectSpread({
    listHeight: listHeight,
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave
  }, props), {}, {
    children: children
  }));
};

exports.ContentListItemWithHover = ContentListItemWithHover;