"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExpandableListItem = exports.ExpandableListContainer = void 0;

var _react = require("react");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _Transition = require("../Transition");

var _ListItemContainer = require("./ListItemContainer");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["item", "expandedItems", "setExpandedItems", "isNestedItem", "accordion"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var ExpandableListContainer = _styledComponents.default.div.withConfig({
  displayName: "ExpandableListItem__ExpandableListContainer",
  componentId: "sc-p3zf2x-0"
})(["display:inline-flex;flex-direction:column;width:100%;overflow:hidden;"]);

exports.ExpandableListContainer = ExpandableListContainer;

var ItemWrapper = _styledComponents.default.div.withConfig({
  displayName: "ExpandableListItem__ItemWrapper",
  componentId: "sc-p3zf2x-1"
})(["background-color:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.background00();
});

/**
 * ExpandableListItem
 *
 * The ExpandableListItem component (recursive component) wraps and builds the item in the list.
 * It may contain an array of nested items, each of which will be wrapped in this
 * component as well.
 *
 */
var ExpandableListItem = _ref2 => {
  var {
    item,
    expandedItems,
    setExpandedItems,
    isNestedItem,
    accordion = false
  } = _ref2,
      props = _objectWithoutProperties(_ref2, _excluded);

  var {
    id,
    label,
    icon,
    selected = false,
    onClick,
    items
  } = item;
  var onChildClick = (0, _react.useCallback)(() => (itemId => {
    var nextExpandedItems = [];

    if (expandedItems.includes(itemId)) {
      // Close the expanded item
      nextExpandedItems = expandedItems.filter(i => i !== itemId);
    } else if (accordion) {
      // Only add one expanded item when accordion
      nextExpandedItems = [id];
    } else {
      // Extend expanded items with a new one
      nextExpandedItems = [...expandedItems, id];
    }

    setExpandedItems(nextExpandedItems);
  })(id), [expandedItems, id, accordion, setExpandedItems]);
  var hasChildren = items !== undefined;
  var onItemClick = hasChildren ? onChildClick : onClick;
  var expanded = expandedItems.includes(id);
  var childSelected = items !== undefined ? Boolean(items.find(_ref3 => {
    var {
      selected: subSelected = false
    } = _ref3;
    return subSelected;
  })) : false;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(ItemWrapper, _objectSpread(_objectSpread({}, props), {}, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_ListItemContainer.ListItemContainer, {
      selected: selected,
      isNestedItem: isNestedItem,
      hasChildren: hasChildren,
      expanded: expanded,
      childSelected: childSelected,
      onClick: onItemClick,
      icon: icon,
      label: label
    }), items !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Transition.FoldTransition, {
      expanded: expanded,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(ExpandableListContainer, {
        children: items.map(i => /*#__PURE__*/(0, _jsxRuntime.jsx)(ExpandableListItem, {
          item: i,
          expandedItems: expandedItems,
          setExpandedItems: setExpandedItems,
          isNestedItem: true,
          accordion: accordion
        }, i.id))
      })
    }) : null]
  }), id);
};

exports.ExpandableListItem = ExpandableListItem;