import { CSSColor, ColorBaseName, SimpleColorBaseName } from './color';
/**
 * Interfaces
 */
declare type TextTransformType = 'none' | 'uppercase';
export interface Font {
    readonly size: {
        readonly smaller: string;
        readonly small: string;
        readonly regular: string;
        readonly large: string;
        readonly larger: string;
    };
    readonly lineHeight: {
        readonly smallest: string;
        readonly smaller: string;
        readonly small: string;
        readonly medium: string;
        readonly large: string;
        readonly larger: string;
    };
    readonly fontWeight: {
        readonly normal: number;
        readonly semibold: number;
        readonly bold: number;
    };
    readonly family: string;
    readonly button: {
        readonly primary: {
            readonly textTransform: TextTransformType;
        };
        readonly secondary: {
            readonly default: {
                readonly textTransform: TextTransformType;
            };
            readonly accent: {
                readonly textTransform: TextTransformType;
            };
        };
    };
    readonly tableHeader: {
        readonly textTransform: TextTransformType;
    };
}
export interface Color {
    readonly text00: CSSColor;
    readonly text01: CSSColor;
    readonly text02: CSSColor;
    readonly text03: CSSColor;
    readonly text04: CSSColor;
    readonly text05: CSSColor;
    readonly text06: CSSColor;
    readonly textLink: CSSColor;
    readonly textLinkHover: CSSColor;
    readonly textPrimary: CSSColor;
    readonly textError: CSSColor;
    readonly background: CSSColor;
    readonly background00: CSSColor;
    readonly background01: CSSColor;
    readonly background02: CSSColor;
    readonly background03: CSSColor;
    readonly background04: CSSColor;
    readonly background05: CSSColor;
    readonly backgroundPrimary: CSSColor;
    readonly backgroundError: CSSColor;
    readonly element01: CSSColor;
    readonly element10: CSSColor;
    readonly element11: CSSColor;
    readonly element12: CSSColor;
    readonly element13: CSSColor;
    readonly element14: CSSColor;
    readonly element15: CSSColor;
    readonly element16: CSSColor;
    readonly elementPrimary: CSSColor;
    readonly elementHalfPrimary: CSSColor;
    readonly elementError: CSSColor;
    readonly elementSuccess: CSSColor;
    readonly elementWarning: CSSColor;
    readonly elementAccent: CSSColor;
    readonly elementBorder: CSSColor;
}
export interface Shadow {
    readonly card: string;
    readonly dialog: string;
    readonly dialogHeaderFooter: string;
    readonly header: string;
    readonly knobOff1: string;
    readonly knobOff2: string;
    readonly knobOn1: string;
    readonly knobOn2: string;
    readonly knobOn3: string;
    readonly menu: string;
    readonly primaryButton: string;
    readonly selectList: string;
    readonly tab: string;
    readonly tableRow: string;
    readonly toast: string;
    readonly tooltip: string;
}
export declare type SelectMarker = 'background' | 'check';
export interface Theme {
    readonly font: Font;
    readonly color: Color;
    readonly shadow: Shadow;
    readonly compact: boolean;
    readonly selectMarker: SelectMarker;
}
/**
 * Default theming
 */
export declare const font: Font;
export declare const generateDefaultTheme: (color: ColorBaseName | SimpleColorBaseName) => Theme;
export declare const defaultTheme: Theme;
export {};
